Index: lib/src/runner/parse_metadata.dart |
diff --git a/lib/src/runner/parse_metadata.dart b/lib/src/runner/parse_metadata.dart |
index dcdb31062ba5d4bacce1bb09146cb0da9a38acbc..1fcbaf072f067d7ed0103337af11dc889e22b76f 100644 |
--- a/lib/src/runner/parse_metadata.dart |
+++ b/lib/src/runner/parse_metadata.dart |
@@ -2,7 +2,7 @@ |
// for details. All rights reserved. Use of this source code is governed by a |
// BSD-style license that can be found in the LICENSE file. |
-library unittest.runner.parse_metadata; |
+library test.runner.parse_metadata; |
import 'dart:io'; |
@@ -25,7 +25,7 @@ Metadata parseMetadata(String path) { |
var directives = parseDirectives(contents, name: path).directives; |
var annotations = directives.isEmpty ? [] : directives.first.metadata; |
// We explicitly *don't* just look for "package:unittest" imports here, |
// because it could be re-exported from another library. |
var prefixes = directives.map((directive) { |
if (directive is! ImportDirective) return null; |
@@ -25,7 +25,7 @@ Metadata parseMetadata(String path) { |
var directives = parseDirectives(contents, name: path).directives; |
var annotations = directives.isEmpty ? [] : directives.first.metadata; |
- // We explicitly *don't* just look for "package:unittest" imports here, |
+ // We explicitly *don't* just look for "package:test" imports here, |
// because it could be re-exported from another library. |
var prefixes = directives.map((directive) { |